Geometric primitives
====================

.. currentmodule:: ordec

.. autoclass:: Vec2R
    :exclude-members: __init__, __new__

.. autoclass:: Rect4R
    :exclude-members: __init__, __new__

.. autoclass:: TD4
    :exclude-members: __init__, __new__

.. autoclass:: D4
    :members:

.. autoclass:: Orientation
